summaryrefslogtreecommitdiff
path: root/compiler/vectorise/Vectorise.hs
diff options
context:
space:
mode:
authorIan Lynagh <igloo@earth.li>2012-06-12 12:22:51 +0100
committerIan Lynagh <igloo@earth.li>2012-06-12 12:22:51 +0100
commit1bb4428cbc194cb959166fc8e12d0edd140e3796 (patch)
treee28b7f49a36830663c36e7fefbbb094a72cfbfe1 /compiler/vectorise/Vectorise.hs
parentfea67bc512433dfb042d262a3d86170190a2ddb1 (diff)
downloadhaskell-1bb4428cbc194cb959166fc8e12d0edd140e3796.tar.gz
Remove the Show Var instance
Diffstat (limited to 'compiler/vectorise/Vectorise.hs')
-rw-r--r--compiler/vectorise/Vectorise.hs4
1 files changed, 2 insertions, 2 deletions
diff --git a/compiler/vectorise/Vectorise.hs b/compiler/vectorise/Vectorise.hs
index 3ac9c5105f..637897d900 100644
--- a/compiler/vectorise/Vectorise.hs
+++ b/compiler/vectorise/Vectorise.hs
@@ -264,7 +264,7 @@ vectTopBinder var inline expr
Just (vdty, _)
| eqType vty vdty -> return ()
| otherwise ->
- cantVectorise ("Type mismatch in vectorisation pragma for " ++ show var) $
+ cantVectorise ("Type mismatch in vectorisation pragma for " ++ showSDoc (ppr var)) $
(text "Expected type" <+> ppr vty)
$$
(text "Inferred type" <+> ppr vdty)
@@ -352,7 +352,7 @@ vectTopRhs recFs var expr
; vectDecl <- lookupVectDecl var
; let isDFun = isDFunId var
; traceVt ("vectTopRhs of " ++ show var ++ info globalScalar isDFun vectDecl ++ ":") $
ppr expr
; rhs globalScalar isDFun vectDecl
@@ -352,7 +352,7 @@ vectTopRhs recFs var expr
; vectDecl <- lookupVectDecl var
; let isDFun = isDFunId var
- ; traceVt ("vectTopRhs of " ++ show var ++ info globalScalar isDFun vectDecl ++ ":") $
+ ; traceVt ("vectTopRhs of " ++ showSDoc (ppr var) ++ info globalScalar isDFun vectDecl ++ ":") $
ppr expr
; rhs globalScalar isDFun vectDecl